==> trilinos_10.0.4.dfsg.orig.tar.gz: trilinos-10.0.4.dfsg.orig/packages/teuchos/src/Teuchos_FileInputSource.hpp <==
// @HEADER
// ***********************************************************************
// 
//                    Teuchos: Common Tools Package
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// ***********************************************************************
// @HEADER

#ifndef Teuchos_FILEINPUTSOURCE_H
#define Teuchos_FILEINPUTSOURCE_H

/*! \file Teuchos_FileInputSource.hpp
    \brief Definition of XMLInputSource derived class for reading XML from a file
*/

#include "Teuchos_ConfigDefs.hpp"
#include "Teuchos_XMLInputSource.hpp"


namespace Teuchos
{
  /** \ingroup XML
   * \brief Instantiation of XMLInputSource class for reading XML from a file.
   */
  class FileInputSource : public XMLInputSource
    {
    public:
      /** \brief Constructor */
      FileInputSource(const std::string& filename);

      /** \brief Destructor */
      virtual ~FileInputSource(){;}

      /** \brief Create a FileInputStream */
      virtual RCP<XMLInputStream> stream() const;

    private:
      std::string filename_;
    };

}
#endif

==> trilinos_10.4.0.dfsg.orig.tar.gz: trilinos-10.4.0.dfsg.orig/packages/teuchos/src/Teuchos_FileInputSource.hpp <==
// @HEADER
// ***********************************************************************
// 
//                    Teuchos: Common Tools Package
//                 Copyright (2004) Sandia Corporation
// 
// Under terms of Contract DE-AC04-94AL85000, there is a non-exclusive
// license for use of this work by or on behalf of the U.S. Government.
// 
// This library is free software; you can redistribute it and/or modify
// it under the terms of the GNU Lesser General Public License as
// published by the Free Software Foundation; either version 2.1 of the
// License, or (at your option) any later version.
//  
// This library is distributed in the hope that it will be useful, but
// WITHOUT ANY WARRANTY; without even the implied warranty of
// MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
// Lesser General Public License for more details.
//  
// You should have received a copy of the GNU Lesser General Public
// License along with this library; if not, write to the Free Software
// Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
// USA
// Questions? Contact Michael A. Heroux (maherou@sandia.gov) 
// 
// ***********************************************************************
// @HEADER

#ifndef Teuchos_FILEINPUTSOURCE_H
#define Teuchos_FILEINPUTSOURCE_H

/*! \file Teuchos_FileInputSource.hpp
    \brief Definition of XMLInputSource derived class for reading XML from a file
*/

#include "Teuchos_ConfigDefs.hpp"
#include "Teuchos_XMLInputSource.hpp"


namespace Teuchos
{
  /** \ingroup XML
   * \brief Instantiation of XMLInputSource class for reading XML from a file.
   */
  class TEUCHOS_LIB_DLL_EXPORT FileInputSource : public XMLInputSource
    {
    public:
      /** \brief Constructor */
      FileInputSource(const std::string& filename);

      /** \brief Destructor */
      virtual ~FileInputSource(){;}

      /** \brief Create a FileInputStream */
      virtual RCP<XMLInputStream> stream() const;

    private:
      std::string filename_;
    };

}
#endif
